#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# Copyright (c) 2019-2024, AllWorldIT
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""IDMS Linux installer exceptions."""

from typing import Any

__all__ = ["IliRuntimeError", "IliUsageError"]


class IliRuntimeError(RuntimeError):
    """Ili exception."""

    _data: str

    def __init__(self, message: str, data: Any = None) -> None:  # noqa: ANN401
        """Initialize the exception."""
        super().__init__(message)
        self._data = data

    @property
    def data(self) -> str:
        """Return the data."""
        return self._data


class IliUsageError(IliRuntimeError):
    """Ili commandline usage exception."""

    def __init__(self, message: str, data: Any = None) -> None:  # noqa: ANN401
        """Initialize the exception."""
        super().__init__(message, data)
