#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# Copyright (c) 2019-2024, AllWorldIT
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""IDMS Linux installer log formatter class."""

import logging
from typing import ClassVar


class IliLogFormatter(logging.Formatter):
    """Custom log formatter with ANSI color support."""

    # ANSI escape codes for colors
    COLORS: ClassVar[dict[str, str]] = {
        "DEBUG": "\033[94m",  # Blue
        "INFO": "\033[92m",  # Green
        "WARNING": "\033[93m",  # Yellow
        "ERROR": "\033[91m",  # Red
        "CRITICAL": "\033[95m",  # Magenta
    }
    RESET = "\033[0m"  # Reset color

    def format(self, record: logging.LogRecord) -> str:
        """Format the log record with ANSI color."""

        # Apply color based on log level
        log_color = self.COLORS.get(record.levelname, self.RESET)

        # Customize log format
        log_format = f"%(asctime)s [{log_color}%(levelname)-8s{self.RESET}] %(message)s"

        # Set the format and return formatted message
        formatter = logging.Formatter(log_format, datefmt="%Y-%m-%d %H:%M:%S")
        return formatter.format(record)
