#!/bin/bash
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# Copyright (c) 2019-2024, AllWorldIT
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

set -eux

mkdir /build


# Create build volume
mkfs.ext4 -F /dev/disk/by-id/scsi-0QEMU_QEMU_HARDDISK_disk1.device
mount -o noatime,discard,nobarrier,nosuid,nodev /dev/disk/by-id/scsi-0QEMU_QEMU_HARDDISK_disk1.device /build

# Check if we have a package cache volume, if we do mount it
has_pkgcache=
if [ -e /dev/disk/by-label/pkgcache ]; then
    mount -o noatime,discard,nobarrier,nosuid,nodev /dev/disk/by-label/pkgcache /var/cache/pacman/pkg
    has_pkgcache=yes
fi

ilitools --verbose \
    create \
        --profile disk-image-raw-serial.profile \
    disk-image \
        --target-image /build/idms-linux-raw-serial-x86_64.raw

echo "Compressing with zstd..."
zstd --verbose --rm "/build/idms-linux-raw-serial-x86_64.raw"

# Unmount package cache volume
if [ -n "$has_pkgcache" ]; then
    umount /var/cache/pacman/pkg
fi